<?php

/**
 * @file
 * The class for sOnr webmining configuration set.
 */

class SonrWebminingConfigurationSet {

  protected $id;
  protected $title;
  protected $connectionId;
  protected $connection;
  protected $config;

  /**
   * Constructor of the SonrWebminingConfigurationSet-class.
   *
   * @param int $config_id
   *   ID of the configuration set
   */
  public function __construct($config_id = 0) {
    // Load configuration set.
    $config_set = db_select('sonr_webmining_sets', 'sws')
      ->fields('sws')
      ->condition('swid', $config_id)
      ->execute()
      ->fetch();

    if ($config_set) {
      $this->id = $config_id;
      $this->title = $config_set->title;
      $this->connectionId = $config_set->sonrid;
      $this->connection = SemanticConnector::getConnection('sonr_server', $config_set->sonrid);

      // Add the config.
      $config = unserialize($config_set->config);
      $complete_config = self::getDefaultConfig();
      if (!is_null($config) && is_array($config)) {
        $complete_config = array_merge($complete_config, $config);
      }
      $this->config = $complete_config;
    }
    else {
      $this->id = 0;
      $this->title = '';
      $this->connectionId = 0;
      $this->connection = SemanticConnector::getConnection('sonr_server', $this->connectionId);
      $this->config = self::getDefaultConfig();
    }
  }

  /**
   * Getter-function for the sOnr webMining ID.
   *
   * @return int
   *   ID of the configuration set
   */
  public function getId() {
    return $this->id;
  }

  /**
   * Getter-function for the title-variable.
   *
   * @return string
   *   Title of the configuration set
   */
  public function getTitle() {
    return $this->title;
  }

  /**
   * Getter-function for the sOnr server ID.
   *
   * @return int
   *   sOnr server ID of the configuration set
   */
  public function getConnectionId() {
    return $this->connectionId;
  }

  /**
   * Getter-function for the sOnr server connection object.
   *
   * @return SemanticConnectorConnection
   *   sOnr server connection object of the configuration set
   */
  public function getConnection() {
    return $this->connection;
  }

  /**
   * Getter-function for the config-variable.
   *
   * @return array
   *   Config of the configuration set
   */
  public function getConfig() {
    return $this->config;
  }

  /**
   * Get the default config of a configuration set.
   *
   * @return array
   *   Config of the configuration set
   */
  public static function getDefaultConfig() {
    return array(
      'first_page_only' => FALSE,
      'items_per_page' => 10,
      'summary_max_chars' => 200,
      'separate_blocks' => FALSE,
      'add_trends' => FALSE,
      'facets_to_show' => array(),
      'time_filter' => NULL,
      'time_filter_years' => NULL,
      'components_order' => array('facets', 'time', 'reset', 'trends'),
      'show_searchbar' => TRUE,
      'ac_max_suggestions' => 10,
      'ac_min_chars' => 3,
      'show_tags' => TRUE,
      'tags_max_items' => 10,
      'show_similar' => TRUE,
      'similar_max_items' => 5,
      'show_sentiment' => FALSE,
      'use_css_file' => TRUE,
      'add_rss_functionality' => FALSE,
      'facet_max_items' => 10,
    );
  }
}
