var sonr_search_bar_value = "";

(function ($) {
Drupal.behaviors.sonr_webmining = {
  attach: function (context) {

    var page = 0;
    var loading = false;
    var items_loaded = null;

    // Set the change event for the filters.
    $("#sonr-webmining-filter-form input:not(.filter-reset), #sonr-webmining-filter-form select").once("sonr_webmining", function() {
      $(this).change(function() {
        // Clear search bar value if checked facet is the same.
        var value = $(this).attr("data-field") + "|" + $(this).val();
        if ($(this).is(":not(:checked)") && sonr_search_bar_value.indexOf(value) >= 0) {
          $("#sonr-webmining-search-bar-form input.form-text").val("");
          sonr_search_bar_value = "";
        }
        ajaxSubmit();
      });
    });

    // Set click event for filter reset button.
    $("#sonr-webmining-filter-form").find(".filter-reset").once("sonr_webmining", function() {
      $(this).click(function() { return reset(); });
    });

    // Set click event for search bar submit button.
    $("#sonr-webmining-search-bar-form .search-bar-submit").once("sonr_webmining", function() {
      $(this).click(function(event) {
        return $("#sonr-webmining-search-bar-form").submit(event);
      });
    });

    // Set click event for search bar reset button.
    $("#sonr-webmining-search-bar-form .search-bar-reset").once("sonr_webmining", function() {
      $(this).click(function() { return reset(); });
    });

    // Set click event for the search bar text field.
    $("#sonr-webmining-search-bar-form input.form-text").once("sonr_webmining", function() {
      $(this).focus(function() {
        // Uncheck facet if is the same and checked.
        var values = sonr_search_bar_value.split('|');
        var name = values[0] + "[" + values[1] +  "]";
        if ($("#sonr-webmining-filter-form input[name='" + name + "']").parent().hasClass("checked")) {
          $("#sonr-webmining-filter-form input[name='" + name + "']").attr("checked", false);
        }
        $(this).val("");
        sonr_search_bar_value = "";
      });
    });

    // Set the submit event for filter form.
    $("#sonr-webmining-filter-form").once("sonr_webmining", function() {
      $(this).submit(function(event) {
        event.preventDefault();
        page = 0;
        loading = false;

        // Collect all data.
        var data = {
          filters: collectFilters(),
          search_bar_value: sonr_search_bar_value
        };

        // Call ajax callback function.
        search(data, page);
      });
    });

    // Set the submit event for the search bar form.
    $("#sonr-webmining-search-bar-form").once("sonr_webmining", function() {
      $(this).submit(function(event) {
        event.preventDefault();
        loading = false;

        // Collect all data.
        var data = {
          filters: collectFilters(),
          search_bar_value: sonr_search_bar_value
        };

        // Call ajax callback function.
        search(data, 0);

        return false;
      });
    });

    // Set click event for similar documents link.
    $("div.view-content .similar-more").once("sonr_webmining", function() {
      var uri = $(this).attr('data-uri');
      $(this).click(function() {
        var container = $(this).next();

        // If the container is empty, then get similars
        // else open or close the container
        if (container.html() == "") {
          getSimilars(uri, $(this).next());
        } else {
          if (container.is(':visible')) {
            container.slideUp();
          } else {
            container. slideDown();
          }
        }
      });
    });

    // Set click event for "show all tags"
    $(".views-field-sonr-webmining-tags .tags-show").once("sonr_webmining", function() {
      $(this).click(function(event) {
        $(this).removeClass("tags-show");
        $(this).attr("title", "");
        $(this).find(".tags-more").addClass("element-hidden");
        $(this).find(".tags-rest").fadeIn();
      });
    });

    // Set the infinity scroll event.
    $("body").once("sonr_webmining", function() {
      if ($("div.view-sonr-webmining-list").hasClass("views-load-more")) {
        $(window).scroll(function() {
          var winTop        = $(window).scrollTop(),
              winHeight     = $(window).height(),
              docHeight     = $(document).height(),
              footerHeight  = $("#footer-wrapper").height(),
              scrollTrigger = 1;

          if (items_loaded == null) {
            items_loaded = $(".view-sonr-webmining-list>div.view-content").children().length;
          }

          if ((items_loaded >= Drupal.settings.sonr_webmining.items_per_page) && ((winTop / (docHeight - winHeight - footerHeight)) >= scrollTrigger)) {
            loadInfinity();
          }
        });
      }
    });

    // Insert a clear:both style after right area
    $(".block-sonr-webmining .sonr-webmining-area-right").once("sonr_webmining", function() {
      $('<div style="clear:both;" />').insertAfter($(this));
    });

    // The filter submit function.
    var ajaxSubmit = function() {
      $("#sonr-webmining-filter-form").submit();
    }

    // The search function.
    var search = function(data, page) {
      $.getJSON(Drupal.settings.basePath + "sonr_webmining/get-results/" + getConfigurationSetId() + "/" + page, data, function(data) {
        // Show result list.
        var content_block = $(".view-sonr-webmining-list").closest(".block-sonr-webmining");
        content_block.children("div").remove();
        content_block.append(data.list);
        items_loaded = $(data.list).find("div.view-content").children().length;

        // Reload autocomplete functionality.
        if (Drupal.settings.sonr_webmining.search_bar) {
          Drupal.behaviors.autocomplete.attach(data.list);
          sonr_search_bar_value = data.search_bar_value;
        }

        // Show the new filter.
        var new_filter_form = $(data.filter);
        new_filter_form.find(".views-exposed-widget").find(".form-checkboxes").each(function() {
          var facet_id = this.id.substr(5);
          if ($(this).children().length == 0) {
            $("#edit-na-form-" + facet_id).parent().parent().parent().slideUp(300);
          }
          else {
            $("#edit-na-form-" + facet_id).parent().parent().parent().slideDown(300);
            $("#edit-" + facet_id).empty().append($(this).html());
            if (typeof(Drupal.behaviors.uniform) != "undefined") {
              $("#edit-" + facet_id + " input").uniform();
            }
            if ($("#edit-" + facet_id + " input:checked").length > 0 && $("#edit-na-form-" + facet_id).hasClass("collapsed")) {
              $("#edit-na-form-" + facet_id + " a.fieldset-title").trigger("click");
            }
          }
        });

        // Refresh the trends-chart if enabled.
        if (new_filter_form.find(".views-exposed-form #edit-trends").length > 0) {
          $(".views-exposed-form #edit-trends").empty();
          if (new_filter_form.find(".views-exposed-form #edit-trends").children().length > 0) {
            $(".views-exposed-form #edit-trends").append(new_filter_form.find(".views-exposed-form #edit-trends").html());
            plotData("trends-placeholder", $.parseJSON($(".views-exposed-form #edit-trends .float-chart-values").text()));
            useTooltipp("trends-placeholder");
          }
        }
        Drupal.behaviors.sonr_webmining.attach(data);
      });
    }

    // The similar documents function.
    var getSimilars = function(uri, container) {
      $.get(Drupal.settings.basePath + "sonr_webmining/get-similars/" + getConfigurationSetId(), {uri:uri}, function(data) {
        $(container).hide().html(data).slideDown();
        Drupal.behaviors.sonr_webmining.attach(data);
      });
    }

    // The load infinity function.
    var loadInfinity = function() {
      if (!loading) {
        loading = true;

        // Collect all data and increase page number.
        page += 1;
        var data = {
          filters: collectFilters()
        };

        // Call ajax callback function.
        $.getJSON(Drupal.settings.basePath + "sonr_webmining/get-results/" + getConfigurationSetId() + "/" + page, data, function(data) {
          // Add new list items.
          items_loaded = $(data.list).find("div.view-content").children().length;
          if (items_loaded > 0) {
            $('.view-sonr-webmining-list>div.view-content').append($(data.list).find('div.view-content').html());
            loading = false;
            Drupal.behaviors.sonr_webmining.attach(data);
          }
        });
      }
    }

    // The reset function.
    var reset = function() {
      sonr_search_bar_value = "";
      var data = {
        filters: new Array(),
        search_bar_value: sonr_search_bar_value
      };
      search(data, 0);
      return false;
    }

    // Gets the sOnr webMining configuration set id from the DOM
    var getConfigurationSetId = function() {
      return $('.view-sonr-webmining-list').parent().attr('data-id');
    }

    // Gets the filter data.
    var collectFilters = function() {
      // Collect the selected filters.
      var $form   = $("#sonr-webmining-filter-form"),
          filters  = new Array();

      $form.find("input:checkbox:checked").each(function () {
        filters.push({field:$(this).attr("data-field"), value:$(this).val()});
      });
      // From - To Textfields
      $form.find('input[name="date_from[date]"], input[name="date_to[date]"]').each(function () {
        if ($(this).val().length) {
          filters.push({field:$(this).attr("data-field"), value:$(this).val()});
        }
      });
      // Select date format
      $form.find('select[name="date_from[date]"]').each(function () {
        var date_length = $(this).val().length;
        if (date_length) {
          if (date_length > 4) {
            filters.push({field:$(this).attr("data-field"), value:$(this).val()});
          }
          else {
            filters.push({field:$(this).attr("data-field"), value:$(this).val() + "-01-01"});
            filters.push({field:"date-to", value:$(this).val() + "-12-31"});
          }
        }
      });

      // Collect search string.
      if (Drupal.settings.sonr_webmining.search_bar) {
        if (sonr_search_bar_value) {
          var values = sonr_search_bar_value.split('|');
          filters.push({field:values[0], value:values[1]});
        }
        else {
          var search_string = $("#edit-search-string").val();
          if (search_string.length) {
            filters.push({field:"dyn_txt_content", value:search_string});
            sonr_search_bar_value = "dyn_txt_content|" + search_string + "|" + search_string;
          }
        }
      }

      return filters;
    }

    /**
     * Overwrites Drupal standard handlers.
     */
    if (Drupal.settings.sonr_webmining.search_bar) {

      /**
       * Overwrites the Drupal standard handler for the "keyup" event.
       */
      Drupal.jsAC.prototype.onkeyup = function (input, e) {
        if (!e) {
          e = window.event;
        }
        switch (e.keyCode) {
          case 16: // Shift.
          case 17: // Ctrl.
          case 18: // Alt.
          case 20: // Caps lock.
          case 33: // Page up.
          case 34: // Page down.
          case 35: // End.
          case 36: // Home.
          case 37: // Left arrow.
          case 38: // Up arrow.
          case 39: // Right arrow.
          case 40: // Down arrow.
            return true;

          case 9:  // Tab.
          case 13: // Enter.
          case 27: // Esc.
            this.hidePopup(e.keyCode);
            return true;

          default: // All other keys.
            if (input.value.length >= Drupal.settings.sonr_webmining.min_chars && !input.readOnly) {
              this.populatePopup();
            }
            else {
              this.hidePopup(e.keyCode);
            }
            return true;
        }
      };

      /**
       * Overwrites the Drupal standard for selecting the item.
       */
      Drupal.jsAC.prototype.select = function (node) {
//        this.input.value = $(node).data('autocompleteValue');
        $("#sonr-webmining-search-bar-form").submit();
      };

      /**
       * Overwrites the Drupal standard for highlighting a suggestion.
       */
      Drupal.jsAC.prototype.highlight = function (node) {
        if (this.selected !== false) {
          $(this.selected).removeClass('selected');
        }
        $(node).addClass('selected');
        this.selected = node;
        sonr_search_bar_value = $(node).data("autocompleteValue") + '|' + $(this.selected).find("div").html();
        $(this.ariaLive).html($(this.selected).html());
      };

      /**
       * Overwrites the Drupal standard for unhighlighting a suggestion.
       */
      Drupal.jsAC.prototype.unhighlight = function (node) {
        $(node).removeClass('selected');
        this.selected = false;
        sonr_search_bar_value = "";
        $(this.ariaLive).empty();
      };

      /**
       * Overwrites the Drupal standard for hiding the autocomplete suggestions.
       */
      Drupal.jsAC.prototype.hidePopup = function (keycode) {
        // Submit search bar form if mousebutton was pressed.
        if (this.selected && $.type(keycode) === 'object') {
          $("#sonr-webmining-search-bar-form").submit();
        }
        // Hide popup.
        var popup = this.popup;
        if (popup) {
          this.popup = null;
          $(popup).fadeOut('fast', function () { $(popup).remove(); });
        }
        this.selected = false;
        $(this.ariaLive).empty();
      };
    }

  }
};

})(jQuery);
